@@ -7,6 +7,7 @@ import time
 from collections import namedtuple
 from queue import Empty
 from random import randint
+from distutils.version import StrictVersion
 
 from .speaker_info import print_speaker_table
 from .utils import (
@@ -137,7 +138,9 @@ def on_off_action(speaker, action, args, soco_function, use_local_speaker_list):
 
 @zero_parameters
 def no_args_no_output(speaker, action, args, soco_function, use_local_speaker_list):
-    if soco_function == "separate_stereo_pair" and float(soco.__version__) < 0.20:
+    if soco_function == "separate_stereo_pair" and StrictVersion(
+        soco.__version__
+    ) < StrictVersion("0.20"):
         error_and_exit("Pairing operations require SoCo v0.20 or greater")
         return False
     getattr(speaker, soco_function)()
@@ -288,9 +291,9 @@ def transport_state(speaker, action, args, soco_function, use_local_speaker_list
     return True
 
 
-@one_parameter
-def play_favourite(speaker, action, args, soco_function, use_local_speaker_list):
-    favourite = args[0]
+def play_favourite_core(speaker, favourite):
+    """Core of the play_favourite action, but doesn't exit on failure
+    """
     fs = speaker.music_library.get_sonos_favorites(complete_result=True)
     the_fav = None
     # Strict match
@@ -318,7 +321,7 @@ def play_favourite(speaker, action, args, soco_function, use_local_speaker_list)
                 "Trying 'play_uri()': URI={}, Metadata={}".format(uri, metadata)
             )
             speaker.play_uri(uri=uri, meta=metadata)
-            return True
+            return True, ""
         except Exception as e:
             e1 = e
             pass
@@ -328,12 +331,22 @@ def play_favourite(speaker, action, args, soco_function, use_local_speaker_list)
             logging.info("Trying 'add_to_queue()'")
             index = speaker.add_to_queue(the_fav, as_next=True)
             speaker.play_from_queue(index, start=True)
-            return True
+            return True, ""
         except Exception as e2:
-            error_and_exit("1: {} | 2:{}".format(str(e1), str(e2)))
-            return False
-    error_and_exit("Favourite '{}' not found".format(args[0]))
-    return False
+            msg = "1: {} | 2: {}".format(str(e1), str(e2))
+            return False, msg
+    msg = "Favourite '{}' not found".format(favourite)
+    return False, msg
+
+
+@one_parameter
+def play_favourite(speaker, action, args, soco_function, use_local_speaker_list):
+    result, msg = play_favourite_core(speaker, args[0])
+    if not result:
+        error_and_exit(msg)
+        return False
+    else:
+        return True
 
 
 @one_parameter
@@ -474,7 +487,9 @@ def sleep_at(speaker, action, args, soco_function, use_local_speaker_list):
 
 @one_parameter
 def group_or_pair(speaker, action, args, soco_function, use_local_speaker_list):
-    if soco_function == "create_stereo_pair" and float(soco.__version__) < 0.20:
+    if soco_function == "create_stereo_pair" and StrictVersion(
+        soco.__version__
+    ) < StrictVersion("0.20"):
         error_and_exit("Pairing operations require SoCo v0.20 or greater")
         return False
     speaker2 = get_speaker(args[0], use_local_speaker_list)
@@ -817,7 +832,7 @@ def wait_stop(speaker, action, args, soco_function, use_local_speaker_list):
     while True:
         try:
             event = sub.events.get(timeout=1.0)
-            if event.variables["transport_state"] != "PLAYING":
+            if event.variables["transport_state"] not in ["PLAYING", "TRANSITIONING"]:
                 logging.info(
                     "Speaker '{}' in state '{}'".format(
                         speaker.player_name, event.variables["transport_state"]
@@ -845,7 +860,13 @@ def wait_stopped_for(speaker, action, args, soco_function, use_local_speaker_lis
             # ToDo: Remove temporary fix for CTRL-C not exiting
             set_sigterm(True)
             event = sub.events.get(timeout=1.0)
-            if event.variables["transport_state"] != "PLAYING":
+            logging.info(
+                "Event received: transport_state = '{}'".format(
+                    event.variables["transport_state"]
+                )
+            )
+            if event.variables["transport_state"] not in ["PLAYING", "TRANSITIONING"]:
+                logging.info("Speaker is not 'PLAYING' or 'TRANSITIONING'")
                 sub.unsubscribe()
                 # ToDo: Should really return here and do this some other way ...
                 #       this is what's requiring the SIGKILL
@@ -864,7 +885,6 @@ def wait_stopped_for(speaker, action, args, soco_function, use_local_speaker_lis
                         "current_transport_state"
                     ]
                     logging.info("Transport state = '{}'".format(state))
-                    current_time = time.time()
                     if state == "PLAYING":
                         # Restart the timer
                         start_time = current_time
@@ -875,6 +895,13 @@ def wait_stopped_for(speaker, action, args, soco_function, use_local_speaker_lis
                         )
                     )
                     time.sleep(poll_interval)
+                    current_time = time.time()
+                logging.info(
+                    "Timer expired after not 'PLAYING' for {}s, total elapsed = {}s".format(
+                        int(current_time - start_time),
+                        int(current_time - original_start_time),
+                    )
+                )
                 set_sigterm(False)
                 return True
         except:
@@ -1070,6 +1097,36 @@ def if_stopped_or_playing(speaker, action, args, soco_function, use_local_speake
         return process_action(speaker, action, args, use_local_speaker_list)
 
 
+@one_parameter
+def cue_favourite(speaker, action, args, soco_function, use_local_speaker_list):
+    """Shortcut to mute, play favourite, stop favourite, and unmute.
+    Preserve the mute state
+    """
+    if not speaker.is_coordinator:
+        error_and_exit(
+            "Action '{}' can only be applied to a coordinator".format(action)
+        )
+        return False
+    unmute = False
+    unmute_group = False
+    if not speaker.mute:
+        speaker.mute = True
+        unmute = True
+    if not speaker.group.mute:
+        speaker.group.mute = True
+        unmute_group = True
+    result, msg = play_favourite_core(speaker, args[0])
+    speaker.stop()
+    if unmute:
+        speaker.mute = False
+    if unmute_group:
+        speaker.group.mute = False
+    if not result:
+        error_and_exit(msg)
+        return False
+    return True
+
+
 def process_action(speaker, action, args, use_local_speaker_list):
     sonos_function = actions.get(action, None)
     if sonos_function:
@@ -1137,6 +1194,7 @@ actions = {
     "playback_state": SonosFunction(transport_state, "get_current_transport_info"),
     "playback": SonosFunction(transport_state, "get_current_transport_info"),
     "state": SonosFunction(transport_state, "get_current_transport_info"),
+    "status": SonosFunction(transport_state, "get_current_transport_info"),
     "play_favourite": SonosFunction(play_favourite, "play_favorite"),
     "play_favorite": SonosFunction(play_favourite, "play_favorite"),
     "favourite": SonosFunction(play_favourite, "play_favorite"),
@@ -1249,4 +1307,8 @@ actions = {
     "qa": SonosFunction(queue_album, ""),
     "queue_track": SonosFunction(queue_track, ""),
     "qt": SonosFunction(queue_track, ""),
+    "cue_favourite": SonosFunction(cue_favourite, ""),
+    "cue_favorite": SonosFunction(cue_favourite, ""),
+    "cue_fav": SonosFunction(cue_favourite, ""),
+    "cf": SonosFunction(cue_favourite, ""),
 }
